<?php

/* ------------------------------------------------------------------------- */
/* INT
/* ------------------------------------------------------------------------- */

include "theme_option/theme_settings.php";
$contact_option = get_option ('lemuralia_contact_settings');
$general_option = get_option ('lemuralia_general_settings');

/* ------------------------------------------------------------------------- */
/* SETUP
/* ------------------------------------------------------------------------- */

function lemuralia_setup() {

	// Enable custom menu
	register_nav_menu( 'top-menu', __( 'Top Menu', 'lemuralia' ) );
	
	add_theme_support( 'automatic-feed-links');
	
	// Enable featured image
	add_theme_support( 'post-thumbnails' );
	
	// Enable custom background
	add_theme_support( 'custom-background', $defaults = array ( 'default-color' => 'f5f5f5')  );
	
	// Custom thumbnail size - blog featured
	add_image_size( 'custom-thumbnail', 500, 300, true );	
	
	// Content width
	if ( ! isset( $content_width ) ) $content_width = 692;
	
	

}
add_action( 'after_setup_theme', 'lemuralia_setup' );	

/* ------------------------------------------------------------------------- */
/* Enqueue JavaScript and CSS
/* ------------------------------------------------------------------------- */

function lemuralia_scripts_styles() {

	
	
	// lemuralia Theme 
	wp_enqueue_script( 'lemuralia-script', get_template_directory_uri() . '/js/script.js', array('jquery'), '', true);
	wp_enqueue_script( 'lemuralia-magnificpopup', get_template_directory_uri() . '/js/magnificpopup.min.js', array('jquery'), '', true);
	wp_enqueue_style( 'lemuralia-style', get_stylesheet_uri());
	wp_enqueue_style( 'lemuralia-colorscheme', get_template_directory_uri() . '/style/' . lemuralia_colorsheme()  . '.css');
	
	if ( is_singular() && get_option( 'thread_comments' ) ) wp_enqueue_script( 'comment-reply' ); 
}

add_action( 'wp_enqueue_scripts', 'lemuralia_scripts_styles' );


/* ------------------------------------------------------------------------- */
/* Color Scheme
/* ------------------------------------------------------------------------- */

function lemuralia_colorsheme() {
	
	global $general_option;
	
	if ( !empty($general_option['general_color']) ) : $color = $general_option['general_color'];
	else : $color = 'darkturquoise'; 	
	endif;
	
	return $color;
	
}

/* ------------------------------------------------------------------------- */
/* Languages
/* ------------------------------------------------------------------------- */

load_theme_textdomain( 'lemuralia', get_template_directory().'/languages' );
 
$locale = get_locale();
$locale_file = get_template_directory()."/languages/$locale.php";
if ( is_readable($locale_file) )
	require_once($locale_file);

/* ------------------------------------------------------------------------- */
/* add_editor_style()
/* ------------------------------------------------------------------------- */

function lemuralia_add_editor_styles() {
 
    add_editor_style( get_stylesheet_uri() );
 
}	
add_action( 'init', 'lemuralia_add_editor_styles' );	

/* ------------------------------------------------------------------------- */
/* Custom Header 
/* ------------------------------------------------------------------------- */

function lemuralia_custom_header_setup() {

	$args = array(
		'default-image' => get_template_directory_uri() . '/images/header/header6.png',
		'height'        => 120,
		'width'         => 1600,
	);
	add_theme_support( 'custom-header', $args );

	register_default_headers( array(
		'header1' => array(
			'url'           => '%s/images/header/header1.png',
			'thumbnail_url' => '%s/images/header/header1.png',
			'description'   => _x( 'Header 1', 'header image description', 'lemuralia' )
		),
		'header2' => array(
			'url'           => '%s/images/header/header2.png',
			'thumbnail_url' => '%s/images/header/header2.png',
			'description'   => _x( 'Header 2', 'header image description', 'lemuralia' )
		),
		'header3' => array(
			'url'           => '%s/images/header/header3.png',
			'thumbnail_url' => '%s/images/header/header3.png',
			'description'   => _x( 'Header 3', 'header image description', 'lemuralia' )
		),
		'header4' => array(
			'url'           => '%s/images/header/header4.png',
			'thumbnail_url' => '%s/images/header/header4.png',
			'description'   => _x( 'Header 4', 'header image description', 'lemuralia' )
		),
		'header5' => array(
			'url'           => '%s/images/header/header5.png',
			'thumbnail_url' => '%s/images/header/header5.png',
			'description'   => _x( 'Header 5', 'header image description', 'lemuralia' )
		),	
		'header6' => array(
			'url'           => '%s/images/header/header6.png',
			'thumbnail_url' => '%s/images/header/header6.png',
			'description'   => _x( 'Header 6', 'header image description', 'lemuralia' )
		),
		'header7' => array(
			'url'           => '%s/images/header/header7.png',
			'thumbnail_url' => '%s/images/header/header7.png',
			'description'   => _x( 'Header 6', 'header image description', 'lemuralia' )
		),
		'header8' => array(
			'url'           => '%s/images/header/header8.png',
			'thumbnail_url' => '%s/images/header/header8.png',
			'description'   => _x( 'Header 6', 'header image description', 'lemuralia' )
		),			
		'header9' => array(
			'url'           => '%s/images/header/header9.png',
			'thumbnail_url' => '%s/images/header/header9.png',
			'description'   => _x( 'Header 6', 'header image description', 'lemuralia' )
		),
		'header10' => array(
			'url'           => '%s/images/header/header10.png',
			'thumbnail_url' => '%s/images/header/header10.png',
			'description'   => _x( 'Header 6', 'header image description', 'lemuralia' )
		),
		
	) );
}
add_action( 'after_setup_theme', 'lemuralia_custom_header_setup', 11 );

/* ------------------------------------------------------------------------- */
/* SIDEBAR WIDGETS
/* ------------------------------------------------------------------------- */	

function lemuralia_widgets_init() {	

	register_sidebar(array(
		'name'          => __('Home', 'lemuralia' ),
		'id'			=> 'home',
		'description' => __( 'This widget is located on home page', 'lemuralia' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	));	
	
	register_sidebar(array(
		'name'          => __('Single Blog', 'lemuralia' ),
		'id'			=> 'single',
		'description' => __( 'This widget is located on each single blog page', 'lemuralia' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	));	
	
	register_sidebar(array(
		'name'          => __('Single Page', 'lemuralia' ),
		'id'			=> 'page',
		'description' => __( 'This widget is located on each single page of the blog', 'lemuralia' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	));		

	register_sidebar(array(
		'name'          => __('Footer', 'lemuralia' ),
		'id'			=> 'footer',
		'description' => __( 'This widget is located on the bottom of your website', 'lemuralia' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s ' . lemuralia_footer_class() . ' ">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	));	
	
}
add_action( 'widgets_init', 'lemuralia_widgets_init' );


/* ------------------------------------------------------------------------- */
/* LOGO
/* ------------------------------------------------------------------------- */	

function lemuralia_logo() {

	global $general_option;

	if ( !empty( $general_option['general_logo'] ) ) : ?>
	
		<a href="<?php echo esc_url( home_url() ); ?>" title="<?php bloginfo( 'name' ); ?>"> 
			<img class="site-logo" src="<?php echo esc_url( $general_option['general_logo'] ); ?>" /> 
		</a>
	
	<?php else : ?>
	
		<h1><a class="site-header-title" title="<?php bloginfo( 'name' ); ?>" href="<?php echo esc_url( home_url() ); ?>"> <?php bloginfo( 'name' ); ?> </a></h1><p class="site-header-description"> <?php bloginfo( 'description'); ?> </p>		
	
	<?php endif; 
	
}

/* ------------------------------------------------------------------------- */
/* Pagination
/* ------------------------------------------------------------------------- */	
	
if ( ! function_exists( 'lemuralia_pagination' ) ) :

	function lemuralia_pagination() {
	
		global $wp_query;

		$big = 999999999;
		
		if ( $wp_query->max_num_pages > 1 ) :
		
		?>

		<div class="row">
				
			<div class="grid-100 padd">
		
				<div class="pagination"> 
		
					<?php
					
					echo paginate_links( array(
						'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
						'format' => '?paged=%#%',
						'current' => max( 1, get_query_var('paged') ),
						'total' => $wp_query->max_num_pages,
						'end_size'     => 0,
						'mid_size'     => 1,
						'prev_text'    => '&laquo;',
						'next_text'    => '&raquo;',
					) );
					
					?> 
		
				</div> <!-- .pagination -->
		
			</div> <!-- .grid-100 .padd -->
		
		</div> <!-- .row -->
		
		<?php
		
		endif;
	}
	
endif;

/* ------------------------------------------------------------------------- */
/* SOCIAL LINKS
/* ------------------------------------------------------------------------- */	

function lumeralia_social_links() {

	global $contact_option;
	
	if ( $contact_option['contact_facebook'] or $contact_option['contact_flickr'] or $contact_option['contact_gplus'] or $contact_option['contact_instagram'] or $contact_option['contact_linkedin'] or $contact_option['contact_pinterest'] or $contact_option['contact_tumblr'] or $contact_option['contact_twitter'] or $contact_option['contact_youtube'] ) : ?>
	
		<div class="grid-50 social">
		
			<ul class="social">
			
				<?php if ( !empty($contact_option['contact_facebook']) ) : 
					
					printf(
						'<li class="facebook"><a href="%1$s" title="%2$s" target="_blank"><span class="icon-facebook"></span></a></li>',
						esc_url( $contact_option['contact_facebook'] ),
						esc_html__( 'Facebook' )
					);
				
				endif;
				
				if ( !empty($contact_option['contact_flickr']) ) : 
					
					printf(
						'<li class="flickr"><a href="%1$s" title="%2$s" target="_blank"><span class="icon-flickr"></span></a></li>',
						esc_url( $contact_option['contact_flickr'] ),
						esc_html__( 'Flickr' )
					);
				
				endif;

				if ( !empty($contact_option['contact_gplus']) ) : 
					
					printf(
						'<li class="gplus"><a href="%1$s" title="%2$s" target="_blank"><span class="icon-gplus"></span></a></li>',
						esc_url( $contact_option['contact_gplus'] ),
						esc_html__( 'Goople+' )
					);
				
				endif;								

				if ( !empty($contact_option['contact_instagram']) ) : 
					
					printf(
						'<li class="instagram"><a href="%1$s" title="%2$s" target="_blank"><span class="icon-instagram"></span></a></li>',
						esc_url( $contact_option['contact_instagram'] ),
						esc_html__( 'Instagram' )
					);
				
				endif;							
			
				if ( !empty($contact_option['contact_linkedin']) ) : 
					
					printf(
						'<li class="linkedin"><a href="%1$s" title="%2$s" target="_blank"><span class="icon-linkedin"></span></a></li>',
						esc_url( $contact_option['contact_linkedin'] ),
						esc_html__( 'Linkedin' )
					);
				
				endif;						
				
				if ( !empty($contact_option['contact_pinterest']) ) : 
					
					printf(
						'<li class="pinterest"><a href="%1$s" title="%2$s" target="_blank"><span class="icon-pinterest"></span></a></li>',
						esc_url( $contact_option['contact_pinterest'] ),
						esc_html__( 'Pinterest' )
					);
				
				endif;							

				if ( !empty($contact_option['contact_tumblr']) ) : 
					
					printf(
						'<li class="tumblr"><a href="%1$s" title="%2$s" target="_blank"><span class="icon-tumblr"></span></a></li>',
						esc_url( $contact_option['contact_tumblr'] ),
						esc_html__( 'Tumblr' )
					);
				
				endif;

				if ( !empty($contact_option['contact_twitter']) ) : 
					
					printf(
						'<li class="twitter"><a href="%1$s" title="%2$s" target="_blank"><span class="icon-twitter"></span></a></li>',
						esc_url( $contact_option['contact_twitter'] ),
						esc_html__( 'Twitter' )
					);
				
				endif;							
				
				if ( !empty($contact_option['contact_youtube']) ) : 
					
					printf(
						'<li class="youtube"><a href="%1$s" title="%2$s" target="_blank"><span class="icon-youtube"></span></a></li>',
						esc_url( $contact_option['contact_youtube'] ),
						esc_html__( 'YouTube' )
					);
				
				endif; ?>
			
			
			</ul> <!-- .social -->
			
			<?php if ( !empty($contact_option['contact_address']) ) : ?>
				<p><span class="icon-location"></span><?php echo $contact_option['contact_address']; ?></p>
			<?php endif; ?>
			
			<?php if ( !empty($contact_option['contact_phone']) || !empty($contact_option['contact_email']) ) : ?>
				<p>
				
				<?php if ( !empty($contact_option['contact_phone']) ) : ?>
					<span class="icon-phone"></span><?php echo $contact_option['contact_phone']; ?>
				<?php endif; ?>	
				
				<?php if ( !empty($contact_option['contact_email']) ) : ?>
					<span class="icon-at"></span><?php echo $contact_option['contact_email']; ?>
				<?php endif; ?>	
				
				</p>
			<?php endif; ?>	
	
		</div>
	
	<?php endif;

}

/* ------------------------------------------------------------------------- */
/* Post Category
/* ------------------------------------------------------------------------- */

function lemuralia_post_category() {

	$cat_ID = array(); 
	$categories = get_the_category(); //get all categories for this post
	
	foreach($categories as $category) {
		array_push( $cat_ID, $category->cat_ID );
	}
	
	return $cat_ID;
}

/* ------------------------------------------------------------------------- */
/* RELATED POST
/* ------------------------------------------------------------------------- */

function lemuralia_relatedpost() {
	
	global $post;
	
	$the_query = new WP_query( array( 'category__in' => lemuralia_post_category(), 'post__not_in' => array($post->ID), 'showposts' => 3, 'orderby' => 'rand' ) );
	
	if ( $the_query->have_posts() and ! is_attachment() ) : ?>
	
		<h3> <?php echo esc_html__( 'Схожие записи', 'lemuralia' ); ?> </h3>
		
		<div id="relatedpost" class="relatedpost">
	
			<?php while ($the_query->have_posts() ) : $the_query->the_post(); ?> 

				<div class="widget">
					<?php if ( has_post_thumbnail() ) ?> 
					<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"> <?php the_post_thumbnail('custom-thumbnail'); ?> </a>
					<p><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a></p>
				</div> <!-- .widget -->
			
			<?php endwhile; ?>
			
		</div> <!-- .relatedpost -->	
			
		<?php wp_reset_postdata();
		
	endif;
	
}

/* ------------------------------------------------------------------------- */
/* POST META
/* ------------------------------------------------------------------------- */

function lemuralia_post_meta() {

	if ( !is_page() ) : ?>
	
	<p class="entry-meta">

		<span class="icon-calendar"></span> <time class="entry-date"><?php echo get_the_date() ?></time> <span class="icon-user"></span> <?php the_author_posts_link(); ?><?php if ( comments_open() ) : echo " <span class='icon-comment'></span> "; comments_popup_link( '<a href="'. get_permalink() .'#respond">' . __( 'Оставить комментарий', 'lemuralia' ), __( '1 комментарий', 'lemuralia' ), __( 'Просмотреть все % комментарий', 'lemuralia' ) ); endif; ?></a>

	</p> <!-- .entry-meta -->
	
	<?php endif; 

}

/* ------------------------------------------------------------------------- */	
/* BREADCRUMB
/* ------------------------------------------------------------------------- */	

function lemuralia_breadcrumb() {
	
	global $post;
	$before = "<li>";
	$after = "</li>";
	
	echo "<div id='breadcrumb' class='breadcrumb'><ul>";

	echo $before . "<a href=" . esc_url( home_url() ) . ">Главная</a>" .$after;
	
	if ( is_single() ) :
		
		$categories = get_the_category();
		
		if ( $categories ) :
		
		echo $before;
		the_category(', ', 'multiple');
		echo $after;
	
		endif;
		
		echo $before;
		the_title();
		echo $after;
		
	elseif ( is_category() ) :
		echo $before;
		echo esc_html__('Рубрики: ', 'lemuralia');
		single_cat_title();
		echo $after;
		
	elseif ( is_page() && !$post->post_parent ) :
		echo $before;
		the_title();
		echo $after;
		
	elseif ( is_page() && $post->post_parent ) :
		$parent_id  = $post->post_parent;
		$breadcrumbs = array();
		
		while ($parent_id) :
			$page = get_page($parent_id);
			$breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
			$parent_id    = $page->post_parent;
		endwhile;
		
		$breadcrumbs = array_reverse($breadcrumbs);
		foreach ($breadcrumbs as $crumb) echo ' ' . $before . $crumb . $after . ' ';
		echo $before;
		the_title();
		echo $after;
		
	elseif ( is_tag() ) :
		echo $before;
		echo esc_html__( 'Теги: ', 'lemuralia' );
		single_tag_title();
		echo $after;
		
	elseif ( is_day() ) :
		echo $before;
		echo esc_html__( 'Архивы: ', 'lemuralia' );
		echo get_the_date();
		echo $after;			
		
	elseif ( is_month() ) :
		echo $before;
		echo esc_html__( 'Архивы: ', 'lemuralia' );
		echo get_the_date();
		echo $after;
	
	elseif ( is_year() ) :
		echo $before;
		echo esc_html__( 'Архив: ', 'lemuralia' );
		echo get_the_date();
		echo $after;
	
	elseif (is_author()) :
		echo $before;
		echo esc_html__( 'Автор: ', 'lemuralia' );
		the_author();
		echo $after;			
		
	elseif (isset($_GET['paged']) && !empty($_GET['paged'])) :
		echo $before;
		echo esc_html__('Архивы сайта', 'lemuralia');
		echo $after;
	
	elseif (is_search()) :
		echo $before;
		echo esc_html__('Результаты поиска по запросу: ', 'lemuralia');
		the_search_query();
		echo $after;
		
	elseif (is_404()) :
		echo $before;
		echo esc_html__('Ошибка 404: ', 'lemuralia');
		the_search_query();	
		echo $after;
		
	endif;
	
	echo "</ul></div>";		

}

/* ------------------------------------------------------------------------- */	
/* FOOTER CLASS
/* ------------------------------------------------------------------------- */

function lemuralia_footer_class() {

	if ( is_active_sidebar('footer') ) :

		$the_sidebars = wp_get_sidebars_widgets();
		$the_sidebars = count( $the_sidebars['footer'] );
		$class = "grid-100";
		
		if ( $the_sidebars == 1 ) : 
			$class = "grid-100"; 
		elseif ( $the_sidebars == 2 ) : 
			$class = "grid-50";
		elseif ( $the_sidebars == 3 ) : 
			$class = "grid-33";
		elseif ( $the_sidebars == 4 ) : 
			$class = "grid-25";
		elseif ( $the_sidebars == 5 ) : 
			$class = "grid-20";	
		endif;
		
		return $class;
	
	endif;

}

/* ------------------------------------------------------------------------- */		
/* wp_link_pages
/* ------------------------------------------------------------------------- */	
	
function lemuralia_wp_link_pages() {

	$defaults = array(
		'before'           => '<div class="pagination">',
		'after'            => '</div>',
		'link_before'      => '<span class="page-numbers">',
		'link_after'       => '</span>',
		'next_or_number'   => 'number',
		'separator'        => ' ',
		'nextpagelink'     => __( '&raquo;', 'lemuralia' ),
		'previouspagelink' => __( '&laquo;', 'lemuralia' ),
		'pagelink'         => '%',
		'echo'             => 1
	);
	
	wp_link_pages($defaults);
	
}	

/* ------------------------------------------------------------------------- */		
/* COMMENTS
/* ------------------------------------------------------------------------- */

function lemuralia_comment($comment, $args, $depth) {

		$GLOBALS['comment'] = $comment;
		extract($args, EXTR_SKIP);

		if ( 'div' == $args['style'] ) {
			$tag = 'div';
			$add_below = 'comment';
		} else {
			$tag = 'li';
			$add_below = 'div-comment';
		}
?>
		<<?php echo $tag ?> <?php comment_class(empty( $args['has_children'] ) ? '' : 'parent') ?> id="comment-<?php comment_ID() ?>">
		
			<?php if ( 'div' != $args['style'] ) : ?>
			
				<div id="div-comment-<?php comment_ID() ?>" class="comment-body">
				
			<?php endif; ?>
			
			<div class="comment-meta commentmetadata">
			
				<div class="comment-meta-user">
				
					<div class="comment-author vcard">
			
						<?php if ($args['avatar_size'] != 0) echo get_avatar( $comment, $args['avatar_size'] ); ?>	
				
					</div> <!-- .comment-author .vcard -->
					
				</div>	<!-- .comment-meta-user -->
				
				<div class="comment-meta-time">
				
					<?php echo get_comment_author_link(); ?><br />
					<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>">
						<?php
							/* translators: 1: date, 2: time */
							printf( __('%1$s - %2$s', 'lemuralia' ), get_comment_date(),  get_comment_time()) ?></a><?php edit_comment_link(__('(Редактировать)', 'lemuralia'),'  ','' );
						?>
						
				</div> <!-- .comment-meta-time -->
				
			</div> <!-- .comment-meta .commentmetadata -->

			<?php if ($comment->comment_approved == '0') : ?>
			
				<em class="comment-awaiting-moderation"><?php _e( 'Ваш комментарий ожидает модерации.', 'lemuralia' ) ?></em><br />
			
			<?php endif; ?>
	
			<?php comment_text() ?>

			<div class="reply">
			
				<?php comment_reply_link(array_merge( $args, array('add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
				
			</div> <!-- .reply -->
		
			<?php if ( 'div' != $args['style'] ) : ?>
			
		</div> <!-- .comment-body -->
		
		<?php endif;

}

/* ------------------------------------------------------------------------- */		
/* Page title
/* ------------------------------------------------------------------------- */

function lemuralia_entry_title() {

	if ( is_home() ) :
	
		echo "<h2>" . esc_html__('Последние записи из блога:') . "</h2>";
		
	elseif ( is_archive() )	:
	
		if ( is_author() ) :
	
			echo "<h2>" . esc_html__('Записи автора ', 'lemuralia') . get_the_author() . ": </h2>";
			
		elseif ( is_tag() )	:
		
			?> <h2> <?php single_tag_title('Записи с меткой ', 'lemuralia'); ?> </h2> <?php
			
		elseif ( is_category() ) :	
		
			?> <h2> <?php single_cat_title('Записи в рубрике ', 'lemuralia'); ?> </h2> <?php
			
		elseif ( is_day() or is_month() or is_year() ) :	
		
			echo "<h2>" . esc_html__('Записи за дату ', 'lemuralia') . get_the_date() . ": </h2>";
		
		endif;
	
	elseif ( is_search() ) :
		
		?> <h2> <?php the_search_query(); ?> </h2> <?php
		
	elseif ( is_404() ) :	
	
		echo "<h2>" . esc_html__('Ошибка 404 ', 'lemuralia') . "</h2>";
	
	endif;
	
}

/* ------------------------------------------------------------------------- */
/* wp_title() Filter
/* ------------------------------------------------------------------------- */

function lemuralia_wp_title( $title ) {

	global $paged, $page;

	if ( is_feed() ) :
		return $title;
	endif;
		
	if ( is_front_page() ) :
		$title = bloginfo('name'); echo ' - '; bloginfo('description'); 
	endif;
	
	if ( !is_front_page() ) :
		$title.= ''.' - '.''.get_bloginfo('name'); 
	endif;

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 ) :
		$title = "$title | " . sprintf( __( 'Страница %s', 'lemuralia' ), max( $paged, $page ) );
	endif;
	
	return $title;
}
add_filter( 'wp_title', 'lemuralia_wp_title', 10, 2 );

?>