<?php

class LemuraliaSettings {

    private $general_settings_key = 'lemuralia_general_settings';
    private $contact_settings_key = 'lemuralia_contact_settings';
    private $options_key = 'lemuralia_options';
    private $settings_tabs = array();

    function __construct() {

		add_action( 'init', array( &$this, 'load_settings' ) );
		add_action( 'admin_init', array( $this, 'register_general_settings' ) );
		add_action( 'admin_init', array( &$this, 'register_contact_settings' ) );
		add_action( 'admin_menu', array( &$this, 'add_admin_menus' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_header' ) );
	}

/* ----------------------------------------------------------------------- */	
/* LOAD VARIABLES
/* ----------------------------------------------------------------------- */	
	
	function load_settings() {
		$this->general_settings = (array) get_option( $this->general_settings_key );
		$this->contact_settings = (array) get_option( $this->contact_settings_key );

		// Merge with defaults
		$this->general_settings = array_merge( array(
			'general_logo' => '',
			'general_color' => 'coral',
		), $this->general_settings );

		$this->contact_settings = array_merge( array(
			'contact_facebook' => '',
			'contact_flickr' => '',
			'contact_gplus' => '',
			'contact_instagram' => '',
			'contact_linkedin' => '',
			'contact_pinterest' => '',
			'contact_tumblr' => '',
			'contact_twitter' => '',
			'contact_youtube' => '',
			'contact_address' => '',
			'contact_phone' => '',
			'contact_email' => '',
		), $this->contact_settings );
	}
/* ----------------------------------------------------------------------- */	
/* GENERAL SECTION AND FIELDS
/* ----------------------------------------------------------------------- */
	
	function register_general_settings() {
		$this->settings_tabs[$this->general_settings_key] = 'General';

		register_setting( $this->general_settings_key, $this->general_settings_key, array( $this, 'general_sanitize' ) );
		add_settings_section( 'section_general', esc_html__( 'General Settings.', 'lemuralia' ), array( &$this, 'section_general_desc' ), $this->general_settings_key );
		add_settings_field( 'general_logo', esc_html('Logo', 'lemuralia'), array( &$this, 'general_logo_callback' ), $this->general_settings_key, 'section_general' );
		add_settings_field( 'general_color', esc_html('Color Scheme', 'lemuralia'), array( &$this, 'general_color_callback' ), $this->general_settings_key, 'section_general' );
	}	
	
	function section_general_desc() { 
		echo esc_html__( 'Manage your general settings.', 'lemuralia' ); 
	}
	
	function general_logo_callback() {
		printf(
			'<input type="text" name="%1$s" size="80" class="logo_image" value="%2$s" placeholder="%3$s" />',
			esc_attr ( $this->general_settings_key ) . '[general_logo]',
			stripslashes( ( $this->general_settings['general_logo']) ), 
			esc_html__('Click on Upload Logo button to upload your logo', 'lemuralia')
		);
		
		printf(
			'<input type="submit" class="image_button button" value="%1$s" />',
			esc_html__('Upload Logo', 'lemuralia')
		);		
		
	}
	
	function general_color_callback() {
		?>
		<select name="<?php echo ( $this->general_settings_key ) . '[general_color]'; ?>" id="<?php echo ( $this->general_settings_key ) . '[general_color]'; ?>">
			<option class="level-0" value="burlywood" <?php selected( $this->general_settings['general_color'], 'burlywood' ); ?>>Burlywood</option>
			<option class="level-0" value="cadetblue" <?php selected( $this->general_settings['general_color'], 'cadetblue' ); ?>>Cadet Blue</option>
			<option class="level-0" value="coral" <?php selected( $this->general_settings['general_color'], 'coral' ); ?>>Coral</option>
			<option class="level-0" value="cornflowerblue" <?php selected( $this->general_settings['general_color'], 'cornflowerblue' ); ?>>Cornflower Blue</option>
			<option class="level-0" value="crimson" <?php selected( $this->general_settings['general_color'], 'crimson' ); ?>>Crimson</option>
			<option class="level-0" value="darkcyan" <?php selected( $this->general_settings['general_color'], 'darkcyan' ); ?>>Dark Cyan</option>
			<option class="level-0" value="darkorange" <?php selected( $this->general_settings['general_color'], 'darkorange' ); ?>>Dark Orange</option>
			<option class="level-0" value="darkorchid" <?php selected( $this->general_settings['general_color'], 'darkorchid' ); ?>>Dark Orchid</option>
			<option class="level-0" value="darkseagreen" <?php selected( $this->general_settings['general_color'], 'darkseagreen' ); ?>>Dark Sea Green</option>
			<option class="level-0" value="darkturquoise" <?php selected( $this->general_settings['general_color'], 'darkturquoise'  ); ?>>Dark Turquoise</option>
			<option class="level-0" value="deeppink" <?php selected( $this->general_settings['general_color'], 'deeppink' ); ?>>Deep Pink</option>			
			<option class="level-0" value="goldenrod" <?php selected( $this->general_settings['general_color'], 'goldenrod' ); ?>>Golden Rod</option>
			<option class="level-0" value="magenta" <?php selected( $this->general_settings['general_color'], 'magenta' ); ?>>Magenta</option>
		</select>
		<?php
	}
	
/* ----------------------------------------------------------------------- */	
/* GENERAL SANITIZE
/* ----------------------------------------------------------------------- */	

function general_sanitize( $input ) {
	
	$new_input = array();
	
	$new_input['general_logo'] = esc_url_raw( $input['general_logo'] );	
	
	$new_input['general_color'] = $input['general_color'];	
	
	return $new_input;
	
}
	
/* ----------------------------------------------------------------------- */	
/* CONTACT SECTION AND FIELDS
/* ----------------------------------------------------------------------- */

	function register_contact_settings() {
		$this->settings_tabs[$this->contact_settings_key] = 'Contact';

		register_setting( $this->contact_settings_key, $this->contact_settings_key, array( $this, 'contact_sanitize' ) );
		add_settings_section( 'section_contact', esc_html__( 'Contact Settings.', 'lemuralia' ) , array( &$this, 'section_contact_desc' ), $this->contact_settings_key );
		add_settings_field( 'contact_facebook', esc_html('Facebook URL', 'lemuralia'), array($this, 'contact_facebook_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_flickr', esc_html('Flickr URL', 'lemuralia'), array($this, 'contact_flickr_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_gplus', esc_html('Google+ URL', 'lemuralia'), array($this, 'contact_gplus_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_instagram', esc_html('Instagram URL', 'lemuralia'), array($this, 'contact_instagram_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_linkedin', esc_html('Linkedin URL', 'lemuralia'), array($this, 'contact_linkedin_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_pinterest', esc_html('Pinterest URL', 'lemuralia'), array($this, 'contact_pinterest_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_tumblr', esc_html('Tumblr URL', 'lemuralia'), array($this, 'contact_tumblr_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_twitter', esc_html('Twitter URL', 'lemuralia'), array($this, 'contact_twitter_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_youtube', esc_html('YouTube URL', 'lemuralia'), array($this, 'contact_youtube_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_address', esc_html('Address', 'lemuralia'), array($this, 'contact_address_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_phone', esc_html('Phone Number', 'lemuralia'), array($this, 'contact_phone_callback'), $this->contact_settings_key, 'section_contact' );
		add_settings_field( 'contact_email', esc_html('Email', 'lemuralia'), array($this, 'contact_email_callback'), $this->contact_settings_key, 'section_contact' );
	}
	
/* ----------------------------------------------------------------------- */	
/* CONTACT FIELDS CALLBACK
/* ----------------------------------------------------------------------- */	

	function section_contact_desc() { 
		echo esc_html__( 'Manage your contact settings.', 'lemuralia' ); 
	}
	
	/* CONTACT FACEBOOK */
	
	function contact_facebook_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_facebook]',
			esc_attr ( $this->contact_settings['contact_facebook'] ),
			esc_html__( 'www.facebook.com/user-or-page-name', 'lemuralia' )			
		);
	
	}
	
	/* CONTACT FLICKR */
	
	function contact_flickr_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_flickr]',
			esc_attr ( $this->contact_settings['contact_flickr'] ),
			esc_html__( 'www.flickr.com/photos/username', 'lemuralia' )			
		);
	
	}	
	
	/* CONTACT GOOGLE PLUS */
	
	function contact_gplus_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_gplus]',
			esc_attr ( $this->contact_settings['contact_gplus'] ),
			esc_html__( 'www.plus.google.com/user-number', 'lemuralia' )			
		);
	
	}

	/* CONTACT INSTAGRAM */
	
	function contact_instagram_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_instagram]',
			esc_attr ( $this->contact_settings['contact_instagram'] ),
			esc_html__( 'www.instagram.com/username', 'lemuralia' )			
		);
	
	}
	
	/* CONTACT LINKEDIN */
	
	function contact_linkedin_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_linkedin]',
			esc_attr ( $this->contact_settings['contact_linkedin'] ),
			esc_html__( 'www.linkedin.com/profile/view?id=id-number', 'lemuralia' )			
		);
	
	}

	/* CONTACT PINTEREST */
	
	function contact_pinterest_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_pinterest]',
			esc_attr ( $this->contact_settings['contact_pinterest'] ),
			esc_html__( 'www.pinterest.com/username', 'lemuralia' )			
		);
	
	}	
	
	/* CONTACT TUMBLR */
	
	function contact_tumblr_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_tumblr]',
			esc_attr ( $this->contact_settings['contact_tumblr'] ),
			esc_html__( 'username.tumblr.com', 'lemuralia' )			
		);
	
	}	
	
	/* CONTACT TWITTER */
	
	function contact_twitter_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_twitter]',
			esc_attr ( $this->contact_settings['contact_twitter'] ),
			esc_html__( 'wwww.twitter.com/username', 'lemuralia' )			
		);
	
	}	
	
	/* CONTACT YOUTUBE */
	
	function contact_youtube_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_youtube]',
			esc_attr ( $this->contact_settings['contact_youtube'] ),
			esc_html__( 'www.youtube.com/user/username', 'lemuralia' )			
		);
	
	}	
	
	/* CONTACT ADDRESS */
	
	function contact_address_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_address]',
			esc_attr ( $this->contact_settings['contact_address'] ),
			esc_html__( 'Av. Street. etc', 'lemuralia' )			
		);
	
	}	

	/* CONTACT PHONE */
	
	function contact_phone_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_phone]',
			esc_attr ( $this->contact_settings['contact_phone'] ),
			esc_html__( '+00 0000 0000', 'lemuralia' )			
		);
	
	}

	/* CONTACT EMAIL */
	
	function contact_email_callback() {
	
		printf(
            '<input type="text" name="%1$s" size="80" value="%2$s" placeholder="%3$s" />',
            esc_attr ( $this->contact_settings_key ) . '[contact_email]',
			esc_attr ( $this->contact_settings['contact_email'] ),
			esc_html__( 'name@provider', 'lemuralia' )			
		);
	
	}

/* ----------------------------------------------------------------------- */	
/* CONTACT SANITIZE
/* ----------------------------------------------------------------------- */	

function contact_sanitize( $input ) {
	
	$new_input = array();
	
	$new_input['contact_facebook'] = ($input['contact_facebook']) ? esc_url_raw($input['contact_facebook']) : '';
	$new_input['contact_flickr'] = ($input['contact_flickr']) ? esc_url_raw($input['contact_flickr']) : '';
	$new_input['contact_gplus'] = ($input['contact_gplus']) ? esc_url_raw($input['contact_gplus']) : '';
	$new_input['contact_instagram'] = ($input['contact_instagram']) ? esc_url_raw($input['contact_instagram']) : '';
	$new_input['contact_linkedin'] = ($input['contact_linkedin']) ? esc_url_raw($input['contact_linkedin']) : '';
	$new_input['contact_pinterest'] = ($input['contact_pinterest']) ? esc_url_raw($input['contact_pinterest']) : '';
	$new_input['contact_tumblr'] = ($input['contact_tumblr']) ? esc_url_raw($input['contact_tumblr']) : '';
	$new_input['contact_twitter'] = ($input['contact_twitter']) ? esc_url_raw($input['contact_twitter']) : '';
	$new_input['contact_youtube'] = ($input['contact_youtube']) ? esc_url_raw($input['contact_youtube']) : '';
	$new_input['contact_address'] = ($input['contact_address']) ? sanitize_text_field($input['contact_address']) : '';
	$new_input['contact_phone'] = ($input['contact_phone']) ? sanitize_text_field($input['contact_phone']) : '';
	$new_input['contact_email'] = ($input['contact_email']) ? sanitize_email($input['contact_email']) : '';
	
	return $new_input;
	
}
	

/* ----------------------------------------------------------------------- */
/* ADD THEME OPTION MENU
/* ----------------------------------------------------------------------- */
	
	function add_admin_menus() {
		add_theme_page( 'Lemuralia Settings', esc_html__('Theme Options', 'lemuralia'), 'edit_theme_options', $this->options_key, array( &$this, 'lemuralia_options_page' ) );
	}

/* ----------------------------------------------------------------------- */
/* TABS 
/* ----------------------------------------------------------------------- */	
	
	function options_tabs() {
		$current_tab = isset( $_GET['tab'] ) ? $_GET['tab'] : $this->general_settings_key;

		screen_icon();
		echo '<h2 class="nav-tab-wrapper">';
		foreach ( $this->settings_tabs as $tab_key => $tab_caption ) {
			$active = $current_tab == $tab_key ? 'nav-tab-active' : '';
			echo '<a class="nav-tab ' . $active . '" href="?page=' . $this->options_key . '&tab=' . $tab_key . '">' . $tab_caption . '</a>';
		}
		echo '</h2>';

	}
	
/* ----------------------------------------------------------------------- */
/* PAGE
/* ----------------------------------------------------------------------- */	
	
	function lemuralia_options_page() {
		$tab = isset( $_GET['tab'] ) ? $_GET['tab'] : $this->general_settings_key;
		?>
		<div class="wrap">
			<?php $this->options_tabs(); ?>
			<form method="post" action="options.php">
				<?php wp_nonce_field( 'update-options' ); ?>
				<?php settings_fields( $tab ); ?>
				<?php do_settings_sections( $tab ); ?>
				<?php submit_button(); ?>
			</form>
		</div>
    <?php
	

	}	
	
	
	function admin_header() {
	
		wp_enqueue_script('admin-script', get_template_directory_uri().'/theme_option/js/script.js', array('jquery'), '', true);
		wp_enqueue_media();
	
	}

}

$LemuraliaSettings = new LemuraliaSettings();

?>